package com.op.mes.service;

import java.util.List;
import com.op.mes.domain.ProRouteLine;

/**
 * 工艺线体关联Service接口
 *
 * @author Open Platform
 * @date 2023-07-13
 */
public interface IProRouteLineService {
	/**
	 * 查询工艺线体关联
	 *
	 * @param recordId 工艺线体关联主键
	 * @return 工艺线体关联
	 */
	public ProRouteLine selectProRouteLineByRecordId(String recordId);

	/**
	 * 查询工艺线体关联列表
	 *
	 * @param proRouteLine 工艺线体关联
	 * @return 工艺线体关联集合
	 */
	public List<ProRouteLine> selectProRouteLineList(ProRouteLine proRouteLine);

	/**
	 * 新增工艺线体关联
	 *
	 * @param proRouteLine 工艺线体关联
	 * @return 结果
	 */
	public int insertProRouteLine(ProRouteLine proRouteLine);

	/**
	 * 修改工艺线体关联
	 *
	 * @param proRouteLine 工艺线体关联
	 * @return 结果
	 */
	public int updateProRouteLine(ProRouteLine proRouteLine);

	/**
	 * 批量删除工艺线体关联
	 *
	 * @param recordIds 需要删除的工艺线体关联主键集合
	 * @return 结果
	 */
	public int deleteProRouteLineByRecordIds(String[] recordIds);

	/**
	 * 删除工艺线体关联信息
	 *
	 * @param recordId 工艺线体关联主键
	 * @return 结果
	 */
	public int deleteProRouteLineByRecordId(String recordId);

    ProRouteLine getList(ProRouteLine proRouteLine);
}
